@@ -14,6 +14,8 @@
 # limitations under the License.
 #
 
+import importlib
+
 import pytest
 
 from merlin_standard_lib import Schema
@@ -50,5 +52,10 @@ def tabular_schema() -> Schema:
     return tabular_testing_data.schema.remove_by_name(["session_id", "session_start", "day_idx"])
 
 
-from tests.tf.conftest import *  # noqa
-from tests.torch.conftest import *  # noqa
+tf = importlib.util.find_spec("tensorflow")
+if tf is not None:
+    from tests.tf.conftest import *  # noqa
+
+torch = importlib.util.find_spec("torch")
+if torch is not None:
+    from tests.torch.conftest import *  # noqa
